# __version__ = '0.2.8'
# add a new class DefaultImage, if the source load failed, source set to default_source
#__version__ = '0.2.9'

# fix bug in ffpyplayer_video.py
#__version__ = '0.2.10'
# fix bug in __init__.py, can not import kivy here
# __version__ = '0.2.11'
# move all the source using opencv to a independent module
# __version__ = '0.2.12'
# move code using pyaudio to a independent module
# __version__ = '0.2.13'
# use json replace ujson because kivy-ios can not compile ujson
# __version__ = '0.2.14'
# delete xcamera module
# __version__ = '0.2.15'
# use apppublic.rsawrap instead of apppublic.rsa
__version__ = '0.2.16'
